@@ -44,13 +44,13 @@
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <kmimetype.h>
 #include <kstandarddirs.h>
 #include <kmdcodec.h>
 #include <kapp.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 // LibKExiv2 includes.
 
@@ -130,15 +130,15 @@ void FlickrTalker::getFrob()
     url.addQueryItem("api_sig", md5);
     kdDebug() << "Get frob url: " << url << endl;
     TQByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, false);
+    TDEIO::TransferJob* job = TDEIO::http_post(url, tmp, false);
 
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            this, TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            this, TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_GETFROB;
     m_authProgressDlg->setLabelText(i18n("Getting the Frob"));
@@ -164,15 +164,15 @@ void FlickrTalker::checkToken(const TQString& token)
     url.addQueryItem("api_sig", md5);
     kdDebug() << "Check token url: " << url << endl;
     TQByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, false);
+    TDEIO::TransferJob* job = TDEIO::http_post(url, tmp, false);
 
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            this, TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            this, TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_CHECKTOKEN;
     m_authProgressDlg->setLabelText(i18n("Checking if previous token is still valid"));
@@ -198,7 +198,7 @@ void FlickrTalker::slotAuthenticate()
     url.addQueryItem("api_sig", md5);
     kdDebug() << "Authenticate url: " << url << endl;
 
-    KApplication::kApplication()->invokeBrowser(url.url());
+    TDEApplication::kApplication()->invokeBrowser(url.url());
     int valueOk = KMessageBox::questionYesNo(TQT_TQWIDGET(kapp->activeWindow()),
                   i18n("Please Follow through the instructions in the browser window and "
                        "return back to press ok if you are authenticated or press No"),
@@ -234,14 +234,14 @@ void FlickrTalker::getToken()
     url.addQueryItem("api_sig", md5);
     kdDebug() << "Get token url: " << url << endl;
     TQByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, false);
+    TDEIO::TransferJob* job = TDEIO::http_post(url, tmp, false);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            this, TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            this, TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_GETTOKEN;
     m_job   = job;
@@ -261,14 +261,14 @@ void FlickrTalker::listPhotoSets()
     url.addQueryItem("api_sig", md5);
     kdDebug() << "List photo sets url: " << url << endl;
     TQByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, false);
+    TDEIO::TransferJob* job = TDEIO::http_post(url, tmp, false);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
 
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            this, TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            this, TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_LISTPHOTOSETS;
     m_job   = job;
@@ -299,14 +299,14 @@ void FlickrTalker::getPhotoProperty(const TQString& method, const TQStringList&
     url.addQueryItem("api_sig", md5);
     kdDebug() << "Get photo property url: " << url << endl;
     TQByteArray tmp;
-    KIO::TransferJob* job = KIO::http_post(url, tmp, false);
+    TDEIO::TransferJob* job = TDEIO::http_post(url, tmp, false);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
 
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            this, TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            this, TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_GETPHOTOPROPERTY;
     m_job   = job;
@@ -433,14 +433,14 @@ bool FlickrTalker::addPhoto(const TQString& photoPath, const FPhotoInfo& info,
 
     form.finish();
 
-    KIO::TransferJob* job = KIO::http_post(url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(url, form.formData(), false);
     job->addMetaData("content-type", form.contentType());
 
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            this, TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            this, TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_ADDPHOTO;
     m_job   = job;
@@ -471,7 +471,7 @@ void FlickrTalker::cancel()
         m_authProgressDlg->hide();
 }
 
-void FlickrTalker::data(KIO::Job*, const TQByteArray& data)
+void FlickrTalker::data(TDEIO::Job*, const TQByteArray& data)
 {
     if (data.isEmpty())
         return;
@@ -547,7 +547,7 @@ void FlickrTalker::slotError(const TQString& error)
 //  kdDebug() << "Not handling the error now will see it later" << endl;
 }
 
-void FlickrTalker::slotResult(KIO::Job *job)
+void FlickrTalker::slotResult(TDEIO::Job *job)
 {
     m_job = 0;
     emit signalBusy(false);
