@@ -39,7 +39,7 @@ public:
 	IntThemeParameter();
 	~IntThemeParameter();
 
-	virtual void init(const TQCString& internalName, const KConfigBase* configFile);
+	virtual void init(const TQCString& internalName, const TDEConfigBase* configFile);
 	virtual TQWidget* createWidget(TQWidget* parent, const TQString& value) const;
 	virtual TQString valueFromWidget(TQWidget*) const;
 
