@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 #include <libkipi/plugin.h>
 
-class KAction;
+class TDEAction;
 
 namespace KIPIHTMLExport {
 
@@ -33,13 +33,13 @@ namespace KIPIHTMLExport {
  */
 class Plugin : public KIPI::Plugin {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 	Plugin(TQObject *parent, const char* name, const TQStringList &args);
 	virtual ~Plugin();
 
-	KIPI::Category category( KAction* action ) const;
+	KIPI::Category category( TDEAction* action ) const;
 	virtual void setup( TQWidget* widget );
 
 private slots:
