@@ -25,7 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <tqlineedit.h>
 
 // KDE
-#include <kconfigbase.h>
+#include <tdeconfigbase.h>
 
 namespace KIPIHTMLExport {
 
