@@ -20,11 +20,11 @@
  *
  * ============================================================ */
 
-#include <kconfig.h>
-#include <klocale.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kdeversion.h>
-#include <kglobalsettings.h>
+#include <tdeversion.h>
+#include <tdeglobalsettings.h>
 #include <kimageeffect.h>
 
 #include <tqtimer.h>
@@ -53,7 +53,7 @@ SlideShowGL::SlideShowGL(const TQValueList<TQPair<TQString, int> >& fileList,
                 WX11BypassWM | WDestructiveClose)
 {
 #if KDE_IS_VERSION(3,2,0)
-    TQRect deskRect = KGlobalSettings::desktopGeometry(this);
+    TQRect deskRect = TDEGlobalSettings::desktopGeometry(this);
     m_deskX      = deskRect.x();
     m_deskY      = deskRect.y();
     m_deskWidth  = deskRect.width();
@@ -98,7 +98,7 @@ SlideShowGL::SlideShowGL(const TQValueList<TQPair<TQString, int> >& fileList,
 
     m_imagesHasComments   = ImagesHasComments;
 
-    m_config = new KConfig("kipirc");
+    m_config = new TDEConfig("kipirc");
     m_config->setGroup("SlideShow Settings");
 
     readSettings();
@@ -544,7 +544,7 @@ void SlideShowGL::montage(TQImage& top, TQImage& bot)
     int bw = bot.width(); int bh = bot.height();
 
     if (tw > bw || th > bh)
-        qFatal("Top Image should be smaller or same size as Bottom Image");
+        tqFatal("Top Image should be smaller or same size as Bottom Image");
 
     if (top.depth() != 32) top = top.convertDepth(32);
     if (bot.depth() != 32) bot = bot.convertDepth(32);
