@@ -51,16 +51,16 @@ extern "C"
 
 #include <kiconloader.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kaboutdata.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 #include <kdatetimewidget.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
 
 // LibKipi includes.
 
@@ -159,7 +159,7 @@ TimeAdjustDialog::TimeAdjustDialog(KIPI::Interface* interface, TQWidget* parent)
 
     d->about = new KIPIPlugins::KPAboutData(I18N_NOOP("Time Adjust"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin for adjusting time stamp of picture files"),
                                            "(c) 2003-2005, Jesper K. Pedersen\n"
                                            "(c) 2006-2008, Gilles Caulier");
@@ -296,7 +296,7 @@ TimeAdjustDialog::~TimeAdjustDialog()
 
 void TimeAdjustDialog::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("timeadjust", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("timeadjust", "kipi-plugins");
 }
 
 void TimeAdjustDialog::slotResetDateToCurrent()
@@ -319,7 +319,7 @@ void TimeAdjustDialog::slotCancel()
 
 void TimeAdjustDialog::readSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("Time Adjust Settings");
 
     int adjType = config.readNumEntry("Adjustment Type", 0);   // add by default.
@@ -338,7 +338,7 @@ void TimeAdjustDialog::readSettings()
 
 void TimeAdjustDialog::saveSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("Time Adjust Settings");
 
     int adjType = 0;              // add
